aboutsummaryrefslogtreecommitdiff
path: root/google/ads/googleads/v2/resources/carrier_constant.proto
diff options
context:
space:
mode:
Diffstat (limited to 'google/ads/googleads/v2/resources/carrier_constant.proto')
-rw-r--r--google/ads/googleads/v2/resources/carrier_constant.proto4
1 files changed, 2 insertions, 2 deletions
diff --git a/google/ads/googleads/v2/resources/carrier_constant.proto b/google/ads/googleads/v2/resources/carrier_constant.proto
index 0a9754c13..44b0b6fc1 100644
--- a/google/ads/googleads/v2/resources/carrier_constant.proto
+++ b/google/ads/googleads/v2/resources/carrier_constant.proto
@@ -39,12 +39,12 @@ message CarrierConstant {
pattern: "carrierConstants/{carrier_constant}"
};
// Immutable. The resource name of the carrier criterion.
// Carrier criterion resource names have the form:
//
// `carrierConstants/{criterion_id}`
string resource_name = 1 [
- (google.api.field_behavior) = IMMUTABLE,
+ (google.api.field_behavior) = OUTPUT_ONLY,
(google.api.resource_reference) = {
type: "googleads.googleapis.com/CarrierConstant"
}
@@ -39,12 +39,12 @@ message CarrierConstant {
pattern: "carrierConstants/{carrier_constant}"
};
- // Immutable. The resource name of the carrier criterion.
+ // Output only. The resource name of the carrier criterion.
// Carrier criterion resource names have the form:
//